==> certmanager-model-v1beta1-6.4.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/OrderListFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface OrderListFluent<A extends OrderListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Order item);
  public A setToItems(Integer index,Order item);
  public A addToItems(io.fabric8.certmanager.api.model.acme.v1beta1.Order... items);
  public A addAllToItems(Collection<Order> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.acme.v1beta1.Order... items);
  public A removeAllFromItems(Collection<Order> items);
  public A removeMatchingFromItems(Predicate<OrderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Order> getItems();
  public List<Order> buildItems();
  public Order buildItem(Integer index);
  public Order buildFirstItem();
  public Order buildLastItem();
  public Order buildMatchingItem(Predicate<OrderBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<OrderBuilder> predicate);
  public A withItems(List<Order> items);
  public A withItems(io.fabric8.certmanager.api.model.acme.v1beta1.Order... items);
  public Boolean hasItems();
  public OrderListFluent.ItemsNested<A> addNewItem();
  public OrderListFluent.ItemsNested<A> addNewItemLike(Order item);
  public OrderListFluent.ItemsNested<A> setNewItemLike(Integer index,Order item);
  public OrderListFluent.ItemsNested<A> editItem(Integer index);
  public OrderListFluent.ItemsNested<A> editFirstItem();
  public OrderListFluent.ItemsNested<A> editLastItem();
  public OrderListFluent.ItemsNested<A> editMatchingItem(Predicate<OrderBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,OrderFluent<OrderListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> certmanager-model-v1beta1-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/OrderListFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface OrderListFluent<A extends OrderListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Order item);
  public A setToItems(int index,Order item);
  public A addToItems(io.fabric8.certmanager.api.model.acme.v1beta1.Order... items);
  public A addAllToItems(Collection<Order> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.acme.v1beta1.Order... items);
  public A removeAllFromItems(Collection<Order> items);
  public A removeMatchingFromItems(Predicate<OrderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Order> getItems();
  public List<Order> buildItems();
  public Order buildItem(int index);
  public Order buildFirstItem();
  public Order buildLastItem();
  public Order buildMatchingItem(Predicate<OrderBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<OrderBuilder> predicate);
  public A withItems(List<Order> items);
  public A withItems(io.fabric8.certmanager.api.model.acme.v1beta1.Order... items);
  public Boolean hasItems();
  public OrderListFluent.ItemsNested<A> addNewItem();
  public OrderListFluent.ItemsNested<A> addNewItemLike(Order item);
  public OrderListFluent.ItemsNested<A> setNewItemLike(int index,Order item);
  public OrderListFluent.ItemsNested<A> editItem(int index);
  public OrderListFluent.ItemsNested<A> editFirstItem();
  public OrderListFluent.ItemsNested<A> editLastItem();
  public OrderListFluent.ItemsNested<A> editMatchingItem(Predicate<OrderBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,OrderFluent<OrderListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
